@@ -14,6 +14,7 @@ module Pajamas
       **html_options
     )
       @text = text.presence
+
       @icon = icon.to_s.presence
       @icon_classes = Array.wrap(icon_classes)
       @icon_only = @icon && icon_only
@@ -38,6 +39,12 @@ module Pajamas
       classes.join(" ")
     end
 
+    def icon_aria_label
+      # Icons should have aria-label="" (empty string) when badge has text
+      # to prevent screen readers from announcing both icon and text
+      icon_only? ? nil : ''
+    end
+
     def icon_only?
       @icon_only
     end
