@@ -5,9 +5,10 @@ module RapidDiffs
     include ButtonHelper
     include DiffHelper
 
-    def initialize(diff_file:, additional_menu_items: [])
+    def initialize(diff_file:, additional_menu_items: [], environment: nil)
       @diff_file = diff_file
       @additional_menu_items = additional_menu_items
+      @environment = environment
     end
 
     def file_title_chunks
@@ -38,10 +39,13 @@ module RapidDiffs
     def menu_items
       [
         view_file_menu_item,
+        view_full_file_menu_item,
+        view_on_environment_menu_item,
+        rich_view_toggle,
         *@additional_menu_items
       ]
-      .filter_map { |item| item unless item.nil? }
-      .sort_by { |item| item[:position] || Float::INFINITY }
+                        .compact
+                        .sort_by { |item| item[:position] || Float::INFINITY }
     end
 
     def heading_id
@@ -83,14 +87,61 @@ module RapidDiffs
       view_path = helpers.project_blob_path(project, helpers.tree_join(commit_sha, file_path))
 
       {
-        text: helpers.safe_format(
-          s_('RapidDiffs|View file at %{commitId}'),
-          commitId: helpers.tag.code(@diff_file.content_sha[0..7])
-        ),
+        text: s_('RapidDiffs|View file at %{codeStart}%{commit}%{codeEnd}'),
+        messageData: {
+          commit: @diff_file.content_sha[0..7]
+        },
         href: view_path,
         extraAttrs: { target: '_blank' },
         position: 1
       }
     end
+
+    def view_full_file_menu_item
+      return if !@diff_file.diffable_text? || expanded? || @diff_file.rendered?
+
+      {
+        text: @diff_file.manually_expanded? ? s_('MRDiff|Show changes only') : s_('MRDiff|Show full file'),
+        extraAttrs: { 'data-click': 'showFullFile', 'data-full': @diff_file.manually_expanded? },
+        position: 50
+      }
+    end
+
+    def expanded?
+      @diff_file.fully_expanded? && !@diff_file.manually_expanded?
+    end
+
+    def view_on_environment_menu_item
+      return unless @environment
+
+      file_path = @diff_file.new_path || @diff_file.old_path
+      commit_sha = @diff_file.content_sha
+
+      environment_path = @environment.external_url_for(file_path, commit_sha)
+      return unless environment_path
+
+      {
+        text: helpers.safe_format(
+          s_('RapidDiffs|View on %{environment}'),
+          environment: @environment.formatted_external_url
+        ),
+        href: environment_path,
+        extraAttrs: { target: '_blank', rel: 'noopener noreferrer' },
+        position: 2
+      }
+    end
+
+    def rich_view_toggle
+      return unless @diff_file.has_renderable?
+
+      {
+        text: @diff_file.rendered? ? s_('RapidDiffs|View plain diff') : s_('RapidDiffs|View rich diff'),
+        extraAttrs: {
+          'data-click': 'toggleRichView',
+          'data-rendered': @diff_file.rendered?.to_json
+        },
+        position: 10
+      }
+    end
   end
 end
