@@ -10,9 +10,10 @@ module RapidDiffs
       end
 
       def virtual_rendering_params
+        return if @diff_file.empty?
+
         {
-          paragraphs_count: paragraphs_count,
-          action_buttons_present: action_buttons_present? ? 1 : 0
+          paragraphs_count: paragraphs_count
         }
       end
 
@@ -23,6 +24,11 @@ module RapidDiffs
       end
 
       def change_description
+        if @diff_file.empty?
+          return _('Empty file added.') if @diff_file.new_file?
+          return _('Empty file deleted.') if @diff_file.deleted_file?
+        end
+
         if @diff_file.new_file?
           _("File added.")
         elsif @diff_file.deleted_file?
@@ -48,6 +54,8 @@ module RapidDiffs
       end
 
       def no_preview_reason
+        return if @diff_file.empty?
+
         if @diff_file.too_large?
           _("File size exceeds preview limit.")
         elsif @diff_file.collapsed?
@@ -69,16 +77,8 @@ module RapidDiffs
         @diff_file.diffable_text? && !@diff_file.too_large?
       end
 
-      def viewable_changed?
-        @diff_file.content_changed?
-      end
-
-      def viewable?
-        @diff_file.deleted_file? || @diff_file.new_file? || @diff_file.renamed_file? || @diff_file.mode_changed?
-      end
-
-      def action_buttons_present?
-        expandable_inline? || expandable? || viewable_changed? || viewable?
+      def file_changed?
+        !@diff_file.new_file? && @diff_file.content_changed?
       end
 
       def important?
@@ -105,13 +105,6 @@ module RapidDiffs
         end
       end
 
-      def paths
-        {
-          old_path: @diff_file.old_path,
-          new_path: @diff_file.new_path
-        }
-      end
-
       def project
         @diff_file.repository.project
       end
