@@ -9,20 +9,24 @@ module ActivityPub
       private
 
       def project
-        return unless params[:project_id] || params[:id]
+        return unless permitted_params[:project_id] || permitted_params[:id]
 
-        path = File.join(params[:namespace_id], params[:project_id] || params[:id])
+        path = File.join(permitted_params[:namespace_id], permitted_params[:project_id] || permitted_params[:id])
 
         @project = find_routable!(Project, path, request.fullpath, extra_authorization_proc: auth_proc)
       end
 
       def auth_proc
-        ->(project) { project.public? && !project.pending_delete? }
+        ->(project) { project.public? && !project.deletion_in_progress? }
       end
 
       def ensure_project_feature_flag
         not_found unless ::Feature.enabled?(:activity_pub_project, project)
       end
+
+      def permitted_params
+        params.permit(:id, :namespace_id, :project_id)
+      end
     end
   end
 end
