@@ -6,7 +6,7 @@ class Explore::SnippetsController < Explore::ApplicationController
   feature_category :source_code_management
 
   def index
-    @snippets = SnippetsFinder.new(current_user, explore: true)
+    @snippets = SnippetsFinder.new(current_user, organization_id: Current.organization.id, explore: true)
       .execute
       .page(pagination_params[:page])
       .without_count
