@@ -22,7 +22,7 @@ module Groups
 
           if result.success?
             flash[:success] = s_('Observability|Welcome to GitLab Observability!')
-            redirect_to group_observability_setup_path(group, provisioning: true)
+            redirect_to group_observability_setup_path(group)
             return
           else
             flash[:alert] = result.message
