@@ -9,7 +9,11 @@ module Groups
       feature_category :observability
       urgency :low
 
-      def show; end
+      def show
+        return if group.observability_group_o11y_setting.present?
+
+        group.build_observability_group_o11y_setting(o11y_service_name: group.id) if provisioning?
+      end
 
       private
 
@@ -20,6 +24,10 @@ module Groups
 
         render_403
       end
+
+      def provisioning?
+        params.permit(:provisioning)[:provisioning] == 'true'
+      end
     end
   end
 end
