@@ -3,10 +3,11 @@
 module Groups
   module Settings
     class AccessTokensController < Groups::ApplicationController
+      include RenderAccessTokens
       include AccessTokensActions
 
       layout 'group_settings'
-      feature_category :authentication_and_authorization
+      feature_category :system_access
 
       alias_method :resource, :group
 
@@ -19,6 +20,10 @@ module Groups
       def represent(tokens)
         ::GroupAccessTokenSerializer.new.represent(tokens, group: resource)
       end
+
+      def rotate_service
+        GroupAccessTokens::RotateService
+      end
     end
   end
 end
